@@ -5,14 +5,13 @@ Certain services related stuff
 
 import enum
 # pylint: disable=import-self
-from . import anti_captcha, deathbycaptcha, rucaptcha, twocaptcha
+from . import anti_captcha, rucaptcha, twocaptcha
 
 
 class CaptchaSolvingService(enum.Enum):
     """ CAPTCHA solving service enumeration """
 
     ANTI_CAPTCHA = "anti-captcha.com"
-    DEATHBYCAPTCHA = "deathbycaptcha.com"
     RUCAPTCHA = "rucaptcha.com"
     TWOCAPTCHA = "2captcha.com"
 
@@ -20,7 +19,6 @@ class CaptchaSolvingService(enum.Enum):
 # supported CAPTCHA solving services
 SOLVING_SERVICE = {
     CaptchaSolvingService.ANTI_CAPTCHA: anti_captcha,
-    CaptchaSolvingService.DEATHBYCAPTCHA: deathbycaptcha,
     CaptchaSolvingService.RUCAPTCHA: rucaptcha,
     CaptchaSolvingService.TWOCAPTCHA: twocaptcha
 }
